==> klayout-0.19.3.tar.gz: klayout-0.19.3/src/gsiDeclDbLayoutUtils.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#include "gsi.h"
#include "dbLayoutUtils.h"

namespace gsi
{

// ---------------------------------------------------------------
//  db::RecursiveShapeIterator binding

template <>
Class<db::RecursiveShapeIterator> Class<db::RecursiveShapeIterator>::decl ("RecursiveShapeIterator", 
  gsi::method ("max_depth=", &db::RecursiveShapeIterator::max_depth, 
    "@brief Specify the maximum hierarchy depth to look into\n"
    "\n"
    "A depth of 0 instructs the iterator to deliver only shapes from the initial cell.\n"
    "The depth must be specified before the shapes are being retrieved.\n"
  ) +
  gsi::method ("shape_flags=", &db::RecursiveShapeIterator::shape_flags, 
    "@brief Specify the shape selection flags\n"
    "\n"
    "The flags are the same then being defined in \\Shapes (the default is Shapes.s_all).\n"
    "The flags must be specified before the shapes are being retrieved.\n"
  ) +
  gsi::method ("trans", &db::RecursiveShapeIterator::trans, 
    "@brief Get the current transformation by which the shapes must be transformed into the initial cell\n"
    "\n"
    "The shapes delivered are not transformed. Instead, this transformation must be applied to \n"
    "get the shape in the coordinate system of the top cell.\n"
  ) +
  gsi::method ("itrans", &db::RecursiveShapeIterator::itrans, 
    "@brief Get the current transformation by which the shapes must be transformed into the initial cell\n"
    "\n"
    "The shapes delivered are not transformed. Instead, this transformation must be applied to \n"
    "get the shape in the coordinate system of the top cell.\n"
    "This method delivers the integer version which is not accurate in the strict sense but delivers\n"
    "integer coordinate shapes. This method is somewhat slower than the 'trans' method.\n"
  ) +
  gsi::method ("shape", &db::RecursiveShapeIterator::shape, 
    "@brief Get the current shape\n"
    "\n"
    "Returns the shape currently referred to by the recursive iterator. \n"
    "This shape is not transformed yet and is located in the current cell.\n"
  ) +
  gsi::method ("at_end", &db::RecursiveShapeIterator::at_end, 
    "@brief End of iterator predicate\n"
    "\n"
    "Returns true, if the iterator is at the end of the sequence\n"
  ) +
  gsi::method ("cell_index", &db::RecursiveShapeIterator::cell_index, 
    "@brief Get the current cell's index \n"
  ) +
  gsi::method ("next", &db::RecursiveShapeIterator::next, 
    "@brief Increment the iterator\n"
    "This moves the iterator to the next shape inside the search scope."
  ) +
  gsi::method ("==", &db::RecursiveShapeIterator::operator==, 
    "@brief Comparison of iterators - equality\n"
    "\n"
    "Two iterators are equal if they point to the same shape.\n"
  ) +
  gsi::method ("!=", &db::RecursiveShapeIterator::operator!=, 
    "@brief Comparison of iterators - inequality\n"
    "\n"
    "Two iterators are not equal if they do not point to the same shape.\n"
  ),
  "@brief An iterator delivering shapes that touch or overlap the given region recursively\n"
  "\n"
  "The iterator can be obtained from a layout, specifying a starting cell, a layer and optionally a region.\n"
  "It simplifies retrieval of shapes from a geometrical region while considering\n"
  "subcells as well.\n"
  "Some options can be specified, i.e. the level to which to look into or\n"
  "shape classes and shape properties. The shapes are retrieved by using the \\shape method,\n"
  "\\next moves to the next shape and \\at_end tells, if the iterator has move shapes to deliver.\n"
  "\n"
  "\\Layout offers three methods to get these iterators: begin_shapes, begin_shapes_touching and begin_shapes_overlapping.\n"
  "\n"
  "This class has been introduced in version 0.18.\n"
);

}

==> klayout-0.21.19.tar.gz: klayout-0.21.19/src/gsiDeclDbLayoutUtils.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#include "gsiDecl.h"
#include "dbLayoutUtils.h"

namespace gsi
{

// ---------------------------------------------------------------
//  db::RecursiveShapeIterator binding

template <>
Class<db::RecursiveShapeIterator> Class<db::RecursiveShapeIterator>::decl ("RecursiveShapeIterator", 
  gsi::method ("max_depth=", &db::RecursiveShapeIterator::max_depth, 
    "@brief Specify the maximum hierarchy depth to look into\n"
    "\n"
    "A depth of 0 instructs the iterator to deliver only shapes from the initial cell.\n"
    "The depth must be specified before the shapes are being retrieved.\n"
  ) +
  gsi::method ("shape_flags=", &db::RecursiveShapeIterator::shape_flags, 
    "@brief Specify the shape selection flags\n"
    "\n"
    "The flags are the same then being defined in \\Shapes (the default is Shapes.s_all).\n"
    "The flags must be specified before the shapes are being retrieved.\n"
  ) +
  gsi::method ("trans", &db::RecursiveShapeIterator::trans, 
    "@brief Get the current transformation by which the shapes must be transformed into the initial cell\n"
    "\n"
    "The shapes delivered are not transformed. Instead, this transformation must be applied to \n"
    "get the shape in the coordinate system of the top cell.\n"
  ) +
  gsi::method ("itrans", &db::RecursiveShapeIterator::itrans, 
    "@brief Get the current transformation by which the shapes must be transformed into the initial cell\n"
    "\n"
    "The shapes delivered are not transformed. Instead, this transformation must be applied to \n"
    "get the shape in the coordinate system of the top cell.\n"
    "This method delivers the integer version which is not accurate in the strict sense but delivers\n"
    "integer coordinate shapes. This method is somewhat slower than the 'trans' method.\n"
  ) +
  gsi::method ("shape", &db::RecursiveShapeIterator::shape, 
    "@brief Get the current shape\n"
    "\n"
    "Returns the shape currently referred to by the recursive iterator. \n"
    "This shape is not transformed yet and is located in the current cell.\n"
  ) +
  gsi::method ("at_end?|#at_end", &db::RecursiveShapeIterator::at_end, 
    "@brief End of iterator predicate\n"
    "\n"
    "Returns true, if the iterator is at the end of the sequence\n"
  ) +
  gsi::method ("cell_index", &db::RecursiveShapeIterator::cell_index, 
    "@brief Get the current cell's index \n"
  ) +
  gsi::method ("next", &db::RecursiveShapeIterator::next, 
    "@brief Increment the iterator\n"
    "This moves the iterator to the next shape inside the search scope."
  ) +
  gsi::method ("==", &db::RecursiveShapeIterator::operator==, 
    "@brief Comparison of iterators - equality\n"
    "\n"
    "Two iterators are equal if they point to the same shape.\n"
  ) +
  gsi::method ("!=", &db::RecursiveShapeIterator::operator!=, 
    "@brief Comparison of iterators - inequality\n"
    "\n"
    "Two iterators are not equal if they do not point to the same shape.\n"
  ),
  "@brief An iterator delivering shapes that touch or overlap the given region recursively\n"
  "\n"
  "The iterator can be obtained from a layout, specifying a starting cell, a layer and optionally a region.\n"
  "It simplifies retrieval of shapes from a geometrical region while considering\n"
  "subcells as well.\n"
  "Some options can be specified, i.e. the level to which to look into or\n"
  "shape classes and shape properties. The shapes are retrieved by using the \\shape method,\n"
  "\\next moves to the next shape and \\at_end tells, if the iterator has move shapes to deliver.\n"
  "\n"
  "\\Layout offers three methods to get these iterators: begin_shapes, begin_shapes_touching and begin_shapes_overlapping.\n"
  "\n"
  "This class has been introduced in version 0.18.\n"
);

}
